@@ -49,7 +49,7 @@ def test_list_inverse():
     # Internal consistency: ulinalg.inv() must coincide with the
     # unumpy.matrix inverse, for square matrices (.I is the
     # pseudo-inverse, for non-square matrices, but inv() is not).
-    assert uarrays_close(unumpy.ulinalg.inv(mat), mat.I)
+    assert uarrays_close(unumpy.ulinalg.inv(mat), mat.I).all()
 
 
 def test_list_pseudo_inverse():
@@ -61,14 +61,14 @@ def test_list_pseudo_inverse():
 
     # Internal consistency: the inverse and the pseudo-inverse yield
     # the same result on square matrices:
-    assert uarrays_close(mat.I, unumpy.ulinalg.pinv(mat), 1e-4)
+    assert uarrays_close(mat.I, unumpy.ulinalg.pinv(mat), 1e-4).all()
     assert uarrays_close(
         unumpy.ulinalg.inv(mat),
         # Support for the optional pinv argument is
         # tested:
         unumpy.ulinalg.pinv(mat, 1e-15),
         1e-4,
-    )
+    ).all()
 
     # Non-square matrices:
     x = ufloat(1, 0.1)
@@ -77,5 +77,5 @@ def test_list_pseudo_inverse():
     mat2 = unumpy.matrix([[x, y], [1, 3 + x], [y, 2 * x]])  # "Tall" matrix
 
     # Internal consistency:
-    assert uarrays_close(mat1.I, unumpy.ulinalg.pinv(mat1, 1e-10))
-    assert uarrays_close(mat2.I, unumpy.ulinalg.pinv(mat2, 1e-8))
+    assert uarrays_close(mat1.I, unumpy.ulinalg.pinv(mat1, 1e-10)).all()
+    assert uarrays_close(mat2.I, unumpy.ulinalg.pinv(mat2, 1e-8)).all()
