@@ -11,7 +11,7 @@ import uncertainties.core as uncert_core
 import uncertainties.umath_core as umath_core
 from uncertainties.ops import partial_derivative
 
-from helpers import numbers_close
+from helpers import nan_close, ufloat_nan_close
 ###############################################################################
 # Unit tests
 
@@ -61,9 +61,9 @@ def test_compound_expression():
     """
 
     x = ufloat(3, 0.1)
-
-    # Prone to numerical errors (but not much more than floats):
-    assert umath_core.tan(x) == umath_core.sin(x) / umath_core.cos(x)
+    y1 = umath_core.tan(x)
+    y2 = umath_core.sin(x) / umath_core.cos(x)
+    assert ufloat_nan_close(y1, y2)
 
 
 def test_numerical_example():
@@ -156,8 +156,11 @@ def test_monte_carlo_comparison():
     # or assert_array_max_ulp. This is relevant for all vectorized
     # occurrences of numbers_close.
 
-    assert numpy.vectorize(numbers_close)(
-        covariances_this_module, covariances_samples, 0.06
+    assert numpy.vectorize(nan_close)(
+        covariances_this_module,
+        covariances_samples,
+        rel_tol=0.06,
+        abs_tol=0.06,
     ).all(), (
         "The covariance matrices do not coincide between"
         " the Monte-Carlo simulation and the direct calculation:\n"
@@ -166,13 +169,13 @@ def test_monte_carlo_comparison():
     )
 
     # The nominal values must be close:
-    assert numbers_close(
+    assert nan_close(
         nominal_value_this_module,
         nominal_value_samples,
         # The scale of the comparison depends on the standard
         # deviation: the nominal values can differ by a fraction of
         # the standard deviation:
-        math.sqrt(covariances_samples[2, 2]) / abs(nominal_value_samples) * 0.5,
+        rel_tol=math.sqrt(covariances_samples[2, 2]) / abs(nominal_value_samples) * 0.5,
     ), (
         "The nominal value (%f) does not coincide with that of"
         " the Monte-Carlo simulation (%f), for a standard deviation of %f."
@@ -241,6 +244,17 @@ def test_math_module():
         assert err_math_args == err_ufloat.args
     else:
         raise Exception("%s exception expected" % exception_class.__name__)
+
+    # Exception message is different for int and float so create the math
+    # exception for float rather than reusing the int one above
+    try:
+        math.log(0.0)
+    except Exception as err_math:
+        # Python 3 does not make exceptions local variables: they are
+        # restricted to their except block:
+        err_math_args = err_math.args
+        exception_class = err_math.__class__
+
     try:
         umath_core.log(ufloat(0, 0))
     except exception_class as err_ufloat:
