@@ -22,8 +22,8 @@ from uncertainties import (
 )
 from uncertainties.ops import partial_derivative
 from helpers import (
-    numbers_close,
-    ufloats_close,
+    nan_close,
+    ufloat_nan_close,
 )
 
 
@@ -33,7 +33,7 @@ except ImportError:
     np = None
 
 
-def test_value_construction():
+def test_ufloat_function_construction():
     """
     Tests the various means of constructing a constant number with
     uncertainty *without a string* (see test_ufloat_fromstr(), for this).
@@ -57,99 +57,82 @@ def test_value_construction():
     assert x.std_dev == 0.14
     assert x.tag == "pi"
 
-    # Negative standard deviations should be caught in a nice way
-    # (with the right exception):
-    try:
-        x = ufloat(3, -0.1)
-    except uncert_core.NegativeStdDev:
-        pass
+    with pytest.raises(uncert_core.NegativeStdDev):
+        _ = ufloat(3, -0.1)
 
-    ## Incorrect forms should not raise any deprecation warning, but
-    ## raise an exception:
-
-    try:
-        ufloat(1)  # Form that has never been allowed
-    except TypeError:
-        pass
-    else:
-        raise Exception("An exception should be raised")
+    with pytest.raises(TypeError):
+        ufloat(1)
 
 
-def test_ufloat_fromstr():
-    "Input of numbers with uncertainties as a string"
+ufloat_from_str_cases = [
+    ("-1.23(3.4)", -1.23, 3.4),
+    ("  -1.23(3.4)  ", -1.23, 3.4),  # Test that leading and trailing spaces are ignored
+    ("-1.34(5)", -1.34, 0.05),
+    ("1(6)", 1, 6),
+    ("3(4.2)", 3, 4.2),
+    ("-9(2)", -9, 2),
+    ("1234567(1.2)", 1234567, 1.2),
+    ("12.345(15)", 12.345, 0.015),
+    ("-12.3456(78)e-6", -12.3456e-6, 0.0078e-6),
+    ("0.29", 0.29, 0.01),
+    ("31.", 31, 1),
+    ("-31.", -31, 1),
+    # The following tests that the ufloat() routine does
+    # not consider '31' like the tuple ('3', '1'), which would
+    # make it expect two numbers (instead of 2 1-character
+    # strings):
+    ("31", 31, 1),
+    ("-3.1e10", -3.1e10, 0.1e10),
+    ("169.0(7)", 169, 0.7),
+    ("-0.1+/-1", -0.1, 1),
+    ("-13e-2+/-1e2", -13e-2, 1e2),
+    ("-14.(15)", -14, 15),
+    ("-100.0(15)", -100, 1.5),
+    ("14.(15)", 14, 15),
+    # Global exponent:
+    ("(3.141+/-0.001)E+02", 314.1, 0.1),
+    ## Pretty-print notation:
+    # ± sign, global exponent (not pretty-printed):
+    ("(3.141±0.001)E+02", 314.1, 0.1),
+    # ± sign, individual exponent:
+    ("3.141E+02±0.001e2", 314.1, 0.1),
+    # ± sign, times symbol, superscript (= full pretty-print):
+    ("(3.141 ± 0.001) × 10²", 314.1, 0.1),
+    ## Others
+    # Forced parentheses:
+    ("(2 +/- 0.1)", 2, 0.1),
+    # NaN uncertainty:
+    ("(3.141±nan)E+02", 314.1, float("nan")),
+    ("3.141e+02+/-nan", 314.1, float("nan")),
+    ("3.4(nan)e10", 3.4e10, float("nan")),
+    # NaN value:
+    ("nan+/-3.14e2", float("nan"), 314),
+    # "Double-floats"
+    ("(-3.1415 +/- 1e-4)e+200", -3.1415e200, 1e196),
+    ("(-3.1415e-10 +/- 1e-4)e+200", -3.1415e190, 1e196),
+    # Special float representation:
+    ("-3(0.)", -3, 0),
+]
 
-    # String representation, and numerical values:
-    tests = {
-        "-1.23(3.4)": (-1.23, 3.4),  # (Nominal value, error)
-        "  -1.23(3.4)  ": (-1.23, 3.4),  # Spaces ignored
-        "-1.34(5)": (-1.34, 0.05),
-        "1(6)": (1, 6),
-        "3(4.2)": (3, 4.2),
-        "-9(2)": (-9, 2),
-        "1234567(1.2)": (1234567, 1.2),
-        "12.345(15)": (12.345, 0.015),
-        "-12.3456(78)e-6": (-12.3456e-6, 0.0078e-6),
-        "0.29": (0.29, 0.01),
-        "31.": (31, 1),
-        "-31.": (-31, 1),
-        # The following tests that the ufloat() routine does
-        # not consider '31' like the tuple ('3', '1'), which would
-        # make it expect two numbers (instead of 2 1-character
-        # strings):
-        "31": (31, 1),
-        "-3.1e10": (-3.1e10, 0.1e10),
-        "169.0(7)": (169, 0.7),
-        "-0.1+/-1": (-0.1, 1),
-        "-13e-2+/-1e2": (-13e-2, 1e2),
-        "-14.(15)": (-14, 15),
-        "-100.0(15)": (-100, 1.5),
-        "14.(15)": (14, 15),
-        # Global exponent:
-        "(3.141+/-0.001)E+02": (314.1, 0.1),
-        ## Pretty-print notation:
-        # ± sign, global exponent (not pretty-printed):
-        "(3.141±0.001)E+02": (314.1, 0.1),
-        # ± sign, individual exponent:
-        "3.141E+02±0.001e2": (314.1, 0.1),
-        # ± sign, times symbol, superscript (= full pretty-print):
-        "(3.141 ± 0.001) × 10²": (314.1, 0.1),
-        ## Others
-        # Forced parentheses:
-        "(2 +/- 0.1)": (2, 0.1),
-        # NaN uncertainty:
-        "(3.141±nan)E+02": (314.1, float("nan")),
-        "3.141e+02+/-nan": (314.1, float("nan")),
-        "3.4(nan)e10": (3.4e10, float("nan")),
-        # NaN value:
-        "nan+/-3.14e2": (float("nan"), 314),
-        # "Double-floats"
-        "(-3.1415 +/- 1e-4)e+200": (-3.1415e200, 1e196),
-        "(-3.1415e-10 +/- 1e-4)e+200": (-3.1415e190, 1e196),
-        # Special float representation:
-        "-3(0.)": (-3, 0),
-    }
 
-    for representation, values in tests.items():
-        # We test the fact that surrounding spaces are removed:
-        representation = "  {}  ".format(representation)
+@pytest.mark.parametrize("input_str,nominal_value,std_dev", ufloat_from_str_cases)
+def test_ufloat_fromstr(input_str, nominal_value, std_dev):
+    num = ufloat_fromstr(input_str)
+    assert nan_close(num.nominal_value, nominal_value)
+    assert nan_close(num.std_dev, std_dev)
+    assert num.tag is None
 
-        # Without tag:
-        num = ufloat_fromstr(representation)
-        assert numbers_close(num.nominal_value, values[0])
-        assert numbers_close(num.std_dev, values[1])
-        assert num.tag is None
+    # With a tag as positional argument:
+    num = ufloat_fromstr(input_str, "test variable")
+    assert nan_close(num.nominal_value, nominal_value)
+    assert nan_close(num.std_dev, std_dev)
+    assert num.tag == "test variable"
 
-        # With a tag as positional argument:
-        num = ufloat_fromstr(representation, "test variable")
-        assert numbers_close(num.nominal_value, values[0])
-        assert numbers_close(num.std_dev, values[1])
-        assert num.tag == "test variable"
-
-        # With a tag as keyword argument:
-        num = ufloat_fromstr(representation, tag="test variable")
-        assert numbers_close(num.nominal_value, values[0])
-        assert numbers_close(num.std_dev, values[1])
-        assert num.tag == "test variable"
+    # With a tag as keyword argument:
+    num = ufloat_fromstr(input_str, tag="test variable")
+    assert nan_close(num.nominal_value, nominal_value)
+    assert nan_close(num.std_dev, std_dev)
+    assert num.tag == "test variable"
 
 
 ###############################################################################
@@ -200,6 +183,13 @@ def test_ufloat_method_derivativs(func_name, ufloat_tuples):
         )
 
 
+def test_calculate_zero_equality():
+    zero = ufloat(0, 0)
+    x = ufloat(1, 0.1)
+    x_zero = x - x
+    assert zero == x_zero
+
+
 def test_copy():
     "Standard copy module integration"
     import gc
@@ -597,35 +587,35 @@ def test_wrapped_func_no_args_no_kwargs():
 
     ## Fully automatic numerical derivatives:
     f_wrapped = uncert_core.wrap(f)
-    assert ufloats_close(f_auto_unc(x, y), f_wrapped(x, y))
+    assert ufloat_nan_close(f_auto_unc(x, y), f_wrapped(x, y))
 
     # Call with keyword arguments:
-    assert ufloats_close(f_auto_unc(y=y, x=x), f_wrapped(y=y, x=x))
+    assert ufloat_nan_close(f_auto_unc(y=y, x=x), f_wrapped(y=y, x=x))
 
     ## Automatic additional derivatives for non-defined derivatives,
     ## and explicit None derivative:
     f_wrapped = uncert_core.wrap(f, [None])  # No derivative for y
-    assert ufloats_close(f_auto_unc(x, y), f_wrapped(x, y))
+    assert ufloat_nan_close(f_auto_unc(x, y), f_wrapped(x, y))
 
     # Call with keyword arguments:
-    assert ufloats_close(f_auto_unc(y=y, x=x), f_wrapped(y=y, x=x))
+    assert ufloat_nan_close(f_auto_unc(y=y, x=x), f_wrapped(y=y, x=x))
 
     ### Explicit derivatives:
 
     ## Fully defined derivatives:
     f_wrapped = uncert_core.wrap(f, [lambda x, y: 2, lambda x, y: math.cos(y)])
 
-    assert ufloats_close(f_auto_unc(x, y), f_wrapped(x, y))
+    assert ufloat_nan_close(f_auto_unc(x, y), f_wrapped(x, y))
 
     # Call with keyword arguments:
-    assert ufloats_close(f_auto_unc(y=y, x=x), f_wrapped(y=y, x=x))
+    assert ufloat_nan_close(f_auto_unc(y=y, x=x), f_wrapped(y=y, x=x))
 
     ## Automatic additional derivatives for non-defined derivatives:
     f_wrapped = uncert_core.wrap(f, [lambda x, y: 2])  # No derivative for y
-    assert ufloats_close(f_auto_unc(x, y), f_wrapped(x, y))
+    assert ufloat_nan_close(f_auto_unc(x, y), f_wrapped(x, y))
 
     # Call with keyword arguments:
-    assert ufloats_close(f_auto_unc(y=y, x=x), f_wrapped(y=y, x=x))
+    assert ufloat_nan_close(f_auto_unc(y=y, x=x), f_wrapped(y=y, x=x))
 
 
 def test_wrapped_func_args_no_kwargs():
@@ -655,12 +645,12 @@ def test_wrapped_func_args_no_kwargs():
 
     ## Fully automatic numerical derivatives:
     f_wrapped = uncert_core.wrap(f)
-    assert ufloats_close(f_auto_unc(x, y, *args), f_wrapped(x, y, *args))
+    assert ufloat_nan_close(f_auto_unc(x, y, *args), f_wrapped(x, y, *args))
 
     ## Automatic additional derivatives for non-defined derivatives,
     ## and explicit None derivative:
     f_wrapped = uncert_core.wrap(f, [None])  # No derivative for y
-    assert ufloats_close(f_auto_unc(x, y, *args), f_wrapped(x, y, *args))
+    assert ufloat_nan_close(f_auto_unc(x, y, *args), f_wrapped(x, y, *args))
 
     ### Explicit derivatives:
 
@@ -675,13 +665,13 @@ def test_wrapped_func_args_no_kwargs():
         ],
     )
 
-    assert ufloats_close(f_auto_unc(x, y, *args), f_wrapped(x, y, *args))
+    assert ufloat_nan_close(f_auto_unc(x, y, *args), f_wrapped(x, y, *args))
 
     ## Automatic additional derivatives for non-defined derivatives:
 
     # No derivative for y:
     f_wrapped = uncert_core.wrap(f, [lambda x, y, *args: 2])
-    assert ufloats_close(f_auto_unc(x, y, *args), f_wrapped(x, y, *args))
+    assert ufloat_nan_close(f_auto_unc(x, y, *args), f_wrapped(x, y, *args))
 
 
 def test_wrapped_func_no_args_kwargs():
@@ -712,10 +702,12 @@ def test_wrapped_func_no_args_kwargs():
 
     ## Fully automatic numerical derivatives:
     f_wrapped = uncert_core.wrap(f)
-    assert ufloats_close(f_auto_unc(x, y, **kwargs), f_wrapped(x, y, **kwargs))
+    assert ufloat_nan_close(f_auto_unc(x, y, **kwargs), f_wrapped(x, y, **kwargs))
 
     # Call with keyword arguments:
-    assert ufloats_close(f_auto_unc(y=y, x=x, **kwargs), f_wrapped(y=y, x=x, **kwargs))
+    assert ufloat_nan_close(
+        f_auto_unc(y=y, x=x, **kwargs), f_wrapped(y=y, x=x, **kwargs)
+    )
 
     ## Automatic additional derivatives for non-defined derivatives,
     ## and explicit None derivative:
@@ -723,26 +715,32 @@ def test_wrapped_func_no_args_kwargs():
     # No derivative for positional-or-keyword parameter y, no
     # derivative for optional-keyword parameter z:
     f_wrapped = uncert_core.wrap(f, [None])
-    assert ufloats_close(f_auto_unc(x, y, **kwargs), f_wrapped(x, y, **kwargs))
+    assert ufloat_nan_close(f_auto_unc(x, y, **kwargs), f_wrapped(x, y, **kwargs))
 
     # Call with keyword arguments:
-    assert ufloats_close(f_auto_unc(y=y, x=x, **kwargs), f_wrapped(y=y, x=x, **kwargs))
+    assert ufloat_nan_close(
+        f_auto_unc(y=y, x=x, **kwargs), f_wrapped(y=y, x=x, **kwargs)
+    )
 
     # No derivative for positional-or-keyword parameter y, no
     # derivative for optional-keyword parameter z:
     f_wrapped = uncert_core.wrap(f, [None], {"z": None})
-    assert ufloats_close(f_auto_unc(x, y, **kwargs), f_wrapped(x, y, **kwargs))
+    assert ufloat_nan_close(f_auto_unc(x, y, **kwargs), f_wrapped(x, y, **kwargs))
 
     # Call with keyword arguments:
-    assert ufloats_close(f_auto_unc(y=y, x=x, **kwargs), f_wrapped(y=y, x=x, **kwargs))
+    assert ufloat_nan_close(
+        f_auto_unc(y=y, x=x, **kwargs), f_wrapped(y=y, x=x, **kwargs)
+    )
 
     # No derivative for positional-or-keyword parameter y, derivative
     # for optional-keyword parameter z:
     f_wrapped = uncert_core.wrap(f, [None], {"z": lambda x, y, **kwargs: 3})
-    assert ufloats_close(f_auto_unc(x, y, **kwargs), f_wrapped(x, y, **kwargs))
+    assert ufloat_nan_close(f_auto_unc(x, y, **kwargs), f_wrapped(x, y, **kwargs))
 
     # Call with keyword arguments:
-    assert ufloats_close(f_auto_unc(y=y, x=x, **kwargs), f_wrapped(y=y, x=x, **kwargs))
+    assert ufloat_nan_close(
+        f_auto_unc(y=y, x=x, **kwargs), f_wrapped(y=y, x=x, **kwargs)
+    )
 
     ### Explicit derivatives:
 
@@ -753,18 +751,22 @@ def test_wrapped_func_no_args_kwargs():
         {"z:": lambda x, y, **kwargs: 3},
     )
 
-    assert ufloats_close(f_auto_unc(x, y, **kwargs), f_wrapped(x, y, **kwargs))
+    assert ufloat_nan_close(f_auto_unc(x, y, **kwargs), f_wrapped(x, y, **kwargs))
     # Call with keyword arguments:
-    assert ufloats_close(f_auto_unc(y=y, x=x, **kwargs), f_wrapped(y=y, x=x, **kwargs))
+    assert ufloat_nan_close(
+        f_auto_unc(y=y, x=x, **kwargs), f_wrapped(y=y, x=x, **kwargs)
+    )
 
     ## Automatic additional derivatives for non-defined derivatives:
 
     # No derivative for y or z:
     f_wrapped = uncert_core.wrap(f, [lambda x, y, **kwargs: 2])
-    assert ufloats_close(f_auto_unc(x, y, **kwargs), f_wrapped(x, y, **kwargs))
+    assert ufloat_nan_close(f_auto_unc(x, y, **kwargs), f_wrapped(x, y, **kwargs))
 
     # Call with keyword arguments:
-    assert ufloats_close(f_auto_unc(y=y, x=x, **kwargs), f_wrapped(y=y, x=x, **kwargs))
+    assert ufloat_nan_close(
+        f_auto_unc(y=y, x=x, **kwargs), f_wrapped(y=y, x=x, **kwargs)
+    )
 
 
 def test_wrapped_func_args_kwargs():
@@ -798,7 +800,7 @@ def test_wrapped_func_args_kwargs():
     ## Fully automatic numerical derivatives:
     f_wrapped = uncert_core.wrap(f)
 
-    assert ufloats_close(
+    assert ufloat_nan_close(
         f_auto_unc(x, y, *args, **kwargs),
         f_wrapped(x, y, *args, **kwargs),
         tolerance=1e-5,
@@ -810,7 +812,7 @@ def test_wrapped_func_args_kwargs():
     # No derivative for positional-or-keyword parameter y, no
     # derivative for optional-keyword parameter z:
     f_wrapped = uncert_core.wrap(f, [None, None, None, lambda x, y, *args, **kwargs: 4])
-    assert ufloats_close(
+    assert ufloat_nan_close(
         f_auto_unc(x, y, *args, **kwargs),
         f_wrapped(x, y, *args, **kwargs),
         tolerance=1e-5,
@@ -819,7 +821,7 @@ def test_wrapped_func_args_kwargs():
     # No derivative for positional-or-keyword parameter y, no
     # derivative for optional-keyword parameter z:
     f_wrapped = uncert_core.wrap(f, [None], {"z": None})
-    assert ufloats_close(
+    assert ufloat_nan_close(
         f_auto_unc(x, y, *args, **kwargs),
         f_wrapped(x, y, *args, **kwargs),
         tolerance=1e-5,
@@ -828,7 +830,7 @@ def test_wrapped_func_args_kwargs():
     # No derivative for positional-or-keyword parameter y, derivative
     # for optional-keyword parameter z:
     f_wrapped = uncert_core.wrap(f, [None], {"z": lambda x, y, *args, **kwargs: 3})
-    assert ufloats_close(
+    assert ufloat_nan_close(
         f_auto_unc(x, y, *args, **kwargs),
         f_wrapped(x, y, *args, **kwargs),
         tolerance=1e-5,
@@ -843,7 +845,7 @@ def test_wrapped_func_args_kwargs():
         {"z:": lambda x, y, *args, **kwargs: 3},
     )
 
-    assert ufloats_close(
+    assert ufloat_nan_close(
         f_auto_unc(x, y, *args, **kwargs),
         f_wrapped(x, y, *args, **kwargs),
         tolerance=1e-5,
@@ -853,7 +855,7 @@ def test_wrapped_func_args_kwargs():
 
     # No derivative for y or z:
     f_wrapped = uncert_core.wrap(f, [lambda x, y, *args, **kwargs: 2])
-    assert ufloats_close(
+    assert ufloat_nan_close(
         f_auto_unc(x, y, *args, **kwargs),
         f_wrapped(x, y, *args, **kwargs),
         tolerance=1e-5,
@@ -898,9 +900,11 @@ def test_wrapped_func():
 
     # The random variables must be the same (full correlation):
 
-    assert ufloats_close(f_wrapped(angle, *[1, angle]), f_auto_unc(angle, *[1, angle]))
+    assert ufloat_nan_close(
+        f_wrapped(angle, *[1, angle]), f_auto_unc(angle, *[1, angle])
+    )
 
-    assert ufloats_close(
+    assert ufloat_nan_close(
         f_wrapped(angle, *[list_value, angle]), f_auto_unc(angle, *[list_value, angle])
     )
 
@@ -917,7 +921,7 @@ def test_wrapped_func():
 
     x = uncert_core.ufloat(10, 1)
 
-    assert numbers_close(
+    assert nan_close(
         f_wrapped(x, "string argument", x, x, x).std_dev, (1 + 2 + 3 + 4) * x.std_dev
     )
 
@@ -953,7 +957,7 @@ def test_wrap_with_kwargs():
     z = ufloat(100, 0.111)
     t = ufloat(0.1, 0.1111)
 
-    assert ufloats_close(
+    assert ufloat_nan_close(
         f_wrapped(x, y, z, t=t), f_auto_unc(x, y, z, t=t), tolerance=1e-5
     )
 
@@ -1060,11 +1064,11 @@ def test_covariances():
     z = -3 * x
     covs = uncert_core.covariance_matrix([x, y, z])
     # Diagonal elements are simple:
-    assert numbers_close(covs[0][0], 0.01)
-    assert numbers_close(covs[1][1], 0.04)
-    assert numbers_close(covs[2][2], 0.09)
+    assert nan_close(covs[0][0], 0.01)
+    assert nan_close(covs[1][1], 0.04)
+    assert nan_close(covs[2][2], 0.09)
     # Non-diagonal elements:
-    assert numbers_close(covs[0][1], -0.02)
+    assert nan_close(covs[0][1], -0.02)
 
 
 ###############################################################################
@@ -1142,9 +1146,9 @@ else:
         covs = uncert_core.covariance_matrix([x, y, z])
 
         # Test of the diagonal covariance elements:
-        assert uarrays_close(
+        assert np.isclose(
             numpy.array([v.std_dev**2 for v in (x, y, z)]), numpy.array(covs).diagonal()
-        )
+        ).all()
 
         # "Inversion" of the covariance matrix: creation of new
         # variables:
@@ -1155,15 +1159,22 @@ else:
         )
 
         # Even the uncertainties should be correctly reconstructed:
-        assert uarrays_close(numpy.array((x, y, z)), numpy.array((x_new, y_new, z_new)))
+        from uncertainties.unumpy.core import nominal_values, std_devs
+
+        orig_uarr = np.array((x, y, z))
+        new_uarr = np.array((x_new, y_new, z_new))
+        assert np.isclose(nominal_values(orig_uarr), nominal_values(new_uarr)).all()
+        assert np.isclose(std_devs(orig_uarr), std_devs(new_uarr)).all()
 
         # ... and the covariances too:
-        assert uarrays_close(
+        assert np.isclose(
             numpy.array(covs),
             numpy.array(uncert_core.covariance_matrix([x_new, y_new, z_new])),
-        )
+        ).all()
 
-        assert uarrays_close(numpy.array([z_new]), numpy.array([-3 * x_new + y_new]))
+        assert uarrays_close(
+            numpy.array([z_new]), numpy.array([-3 * x_new + y_new])
+        ).all()
 
         ####################
 
@@ -1182,17 +1193,17 @@ else:
             [x.nominal_value for x in [u, v, sum_value]], cov_matrix
         )
 
-        # uarrays_close() is used instead of numbers_close() because
-        # it compares uncertainties too:
-        assert uarrays_close(numpy.array([u]), numpy.array([u2]))
-        assert uarrays_close(numpy.array([v]), numpy.array([v2]))
-        assert uarrays_close(numpy.array([sum_value]), numpy.array([sum2]))
-        assert uarrays_close(numpy.array([0]), numpy.array([sum2 - (u2 + 2 * v2)]))
+        assert nan_close(u.n, u2.n)
+        assert nan_close(v.n, v2.n)
+        assert nan_close(sum_value.n, sum2.n)
+        assert nan_close(sum_value.s, sum2.s)
+        assert nan_close(0, (sum2 - (u2 + 2 * v2)).n)
+        assert nan_close(0, (sum2 - (u2 + 2 * v2)).s, abs_tol=1e-6)
 
         # Spot checks of the correlation matrix:
         corr_matrix = uncert_core.correlation_matrix([u, v, sum_value])
-        assert numbers_close(corr_matrix[0, 0], 1)
-        assert numbers_close(corr_matrix[1, 2], 2 * v.std_dev / sum_value.std_dev)
+        assert nan_close(corr_matrix[0, 0], 1)
+        assert nan_close(corr_matrix[1, 2], 2 * v.std_dev / sum_value.std_dev)
 
         ####################
 
@@ -1208,11 +1219,11 @@ else:
         # Since the numbers are very small, we need to compare them
         # in a stricter way, that handles the case of a 0 variance
         # in `variables`:
-        assert numbers_close(
-            1e66 * cov[0, 0], 1e66 * variables[0].s ** 2, tolerance=1e-5
+        assert nan_close(
+            1e66 * cov[0, 0], 1e66 * variables[0].s ** 2, rel_tol=1e-5, abs_tol=1e-5
         )
-        assert numbers_close(
-            1e66 * cov[1, 1], 1e66 * variables[1].s ** 2, tolerance=1e-5
+        assert nan_close(
+            1e66 * cov[1, 1], 1e66 * variables[1].s ** 2, rel_tol=1e-5, abs_tol=1e-5
         )
 
         ####################
@@ -1226,10 +1237,12 @@ else:
         variables = uncert_core.correlated_values(nom_values, cov)
 
         for variable, nom_value, variance in zip(variables, nom_values, cov.diagonal()):
-            assert numbers_close(variable.n, nom_value)
-            assert numbers_close(variable.s**2, variance)
+            assert nan_close(variable.n, nom_value)
+            assert nan_close(variable.s**2, variance)
 
-        assert uarrays_close(cov, numpy.array(uncert_core.covariance_matrix(variables)))
+        assert np.isclose(
+            cov, numpy.array(uncert_core.covariance_matrix(variables))
+        ).all()
 
     def test_correlated_values_correlation_mat():
         """
@@ -1267,18 +1280,21 @@ else:
         # it compares uncertainties too:
 
         # Test of individual variables:
-        assert uarrays_close(numpy.array([x]), numpy.array([x2]))
-        assert uarrays_close(numpy.array([y]), numpy.array([y2]))
-        assert uarrays_close(numpy.array([z]), numpy.array([z2]))
+        assert nan_close(x.n, x2.n)
+        assert nan_close(x.s, x2.s)
+        assert nan_close(y.n, y2.n)
+        assert nan_close(y.s, y2.s)
+        assert nan_close(z.n, z2.n)
+        assert nan_close(z.s, z2.s)
 
-        # Partial correlation test:
-        assert uarrays_close(numpy.array([0]), numpy.array([z2 - (-3 * x2 + y2)]))
+        assert nan_close(0, (z2 - (-3 * x2 + y2)).n)
+        assert nan_close(0, (z2 - (-3 * x2 + y2)).s, abs_tol=1e-6)
 
         # Test of the full covariance matrix:
-        assert uarrays_close(
+        assert np.isclose(
             numpy.array(cov_mat),
             numpy.array(uncert_core.covariance_matrix([x2, y2, z2])),
-        )
+        ).all()
 
 
 @pytest.mark.skipif(
@@ -1332,6 +1348,11 @@ def test_deprecated_method(method_name):
             getattr(x, method_name)(y)
 
 
+def test_deprecated_bool():
+    with pytest.warns(FutureWarning, match="is deprecated.*will defer to"):
+        bool(ufloat(0, 0))
+
+
 def test_zero_std_dev_warn():
     with pytest.warns(UserWarning, match="std_dev==0.*unexpected results"):
         ufloat(1, 0)
